==> common-2.0.2-20240520.081815-17-sources.jar: cc/lechun/framework/common/vo/portal/PortalMessageAcceptVo.java <==
package cc.lechun.framework.common.vo.portal;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class PortalMessageAcceptVo implements Serializable {
    private static final long serialVersionUID = 1607024355L;
    /*消息分类ID，必填*/
    private String messageClassId;
    /*消息ID，一般指消息的主键，用来处理消息作为唯一标识使用，非必填，可通过后台配置*/
    private String messagePrimaryKey;
    /*接口返回的数据，支持list，对象，String/Integer等 非必填*/
    private Object data;

    /*消息来源用户，非必填*/
    private String messageFromUserId;

    /*消息title 非必填*/
    private String messageTitle;

    /*消息头 非必填*/
    private String messageHead;
    /*消息体 非必填*/
    private String messageBody;
    /*消息尾 非必填*/
    private String messageTail;

    /*消息备注 非必填*/
    private String messageRemark;

    /*消息时间 非必填，默认取当前时间*/
    private Date messageTime;
    /*用户ID，多个用户用逗号分隔 非必填*/
    private String toUserIds;

    private Integer mergeSend;

    public Integer getMergeSend() {
        return mergeSend;
    }

    public void setMergeSend(Integer mergeSend) {
        this.mergeSend = mergeSend;
    }

    public Object getData() {
        return data;
    }

    public void setData(Object data) {
        this.data = data;
    }

    public String getMessageClassId() {
        return messageClassId;
    }

    public void setMessageClassId(String messageClassId) {
        this.messageClassId = messageClassId;
    }

    public String getMessagePrimaryKey() {
        return messagePrimaryKey;
    }

    public void setMessagePrimaryKey(String messagePrimaryKey) {
        this.messagePrimaryKey = messagePrimaryKey;
    }

    public String getMessageFromUserId() {
        return messageFromUserId;
    }

    public void setMessageFromUserId(String messageFromUserId) {
        this.messageFromUserId = messageFromUserId;
    }

    public String getMessageTitle() {
        return messageTitle;
    }

    public void setMessageTitle(String messageTitle) {
        this.messageTitle = messageTitle;
    }

    public String getMessageHead() {
        return messageHead;
    }

    public void setMessageHead(String messageHead) {
        this.messageHead = messageHead;
    }

    public String getMessageBody() {
        return messageBody;
    }

    public void setMessageBody(String messageBody) {
        this.messageBody = messageBody;
    }

    public String getMessageTail() {
        return messageTail;
    }

    public void setMessageTail(String messageTail) {
        this.messageTail = messageTail;
    }

    public String getMessageRemark() {
        return messageRemark;
    }

    public void setMessageRemark(String messageRemark) {
        this.messageRemark = messageRemark;
    }

    public Date getMessageTime() {
        return messageTime;
    }

    public void setMessageTime(Date messageTime) {
        this.messageTime = messageTime;
    }

    public String getToUserIds() {
        return toUserIds;
    }

    public void setToUserIds(String toUserIds) {
        this.toUserIds = toUserIds;
    }
}

==> common-3.0.0-20241021.031248-2-sources.jar: cc/lechun/framework/common/vo/portal/PortalMessageAcceptVo.java <==
package cc.lechun.framework.common.vo.portal;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class PortalMessageAcceptVo implements Serializable {
    private static final long serialVersionUID = 1607024355L;
    /*消息分类ID，必填*/
    private String messageClassId;
    /*消息ID，一般指消息的主键，用来处理消息作为唯一标识使用，非必填，可通过后台配置*/
    private String messagePrimaryKey;
    /*接口返回的数据，支持list，对象等 必填*/
    private Object data;

    /*消息来源用户，非必填*/
    private String messageFromUserId;

    /*消息title 非必填*/
    private String messageTitle;

    /*消息头 非必填*/
    private String messageHead;
    /*消息体 非必填*/
    private String messageBody;
    /*消息尾 非必填*/
    private String messageTail;

    /*消息备注 非必填*/
    private String messageRemark;

    /*消息时间 非必填，默认取当前时间*/
    private Date messageTime;
    /*用户ID，多个用户用逗号分隔 非必填*/
    private String toUserIds;
    /*合并发送，0不合并，1合并 非必填*/
    private Integer mergeSend;
    /*推送列表，选择推送方式以及推送给谁 必填*/
    private List<PublicMessageClassPushVo> publicMessageClassPushVos;
    public Integer getMergeSend() {
        return mergeSend;
    }

    public void setMergeSend(Integer mergeSend) {
        this.mergeSend = mergeSend;
    }

    public Object getData() {
        return data;
    }

    public void setData(Object data) {
        this.data = data;
    }

    public String getMessageClassId() {
        return messageClassId;
    }

    public void setMessageClassId(String messageClassId) {
        this.messageClassId = messageClassId;
    }

    public String getMessagePrimaryKey() {
        return messagePrimaryKey;
    }

    public void setMessagePrimaryKey(String messagePrimaryKey) {
        this.messagePrimaryKey = messagePrimaryKey;
    }

    public String getMessageFromUserId() {
        return messageFromUserId;
    }

    public void setMessageFromUserId(String messageFromUserId) {
        this.messageFromUserId = messageFromUserId;
    }

    public String getMessageTitle() {
        return messageTitle;
    }

    public void setMessageTitle(String messageTitle) {
        this.messageTitle = messageTitle;
    }

    public String getMessageHead() {
        return messageHead;
    }

    public void setMessageHead(String messageHead) {
        this.messageHead = messageHead;
    }

    public String getMessageBody() {
        return messageBody;
    }

    public void setMessageBody(String messageBody) {
        this.messageBody = messageBody;
    }

    public String getMessageTail() {
        return messageTail;
    }

    public void setMessageTail(String messageTail) {
        this.messageTail = messageTail;
    }

    public String getMessageRemark() {
        return messageRemark;
    }

    public void setMessageRemark(String messageRemark) {
        this.messageRemark = messageRemark;
    }

    public Date getMessageTime() {
        return messageTime;
    }

    public void setMessageTime(Date messageTime) {
        this.messageTime = messageTime;
    }

    public String getToUserIds() {
        return toUserIds;
    }

    public void setToUserIds(String toUserIds) {
        this.toUserIds = toUserIds;
    }

    public List<PublicMessageClassPushVo> getPublicMessageClassPushVos() {
        return publicMessageClassPushVos;
    }

    public void setPublicMessageClassPushVos(List<PublicMessageClassPushVo> publicMessageClassPushVos) {
        this.publicMessageClassPushVos = publicMessageClassPushVos;
    }
}
